@@ -16,7 +16,7 @@ class Hakaimg(Depot):
         return DepotType.Hakaimg
 
     # 上传图片, 二进制内容
-    def upload(self, content) -> Optional[str]:
+    def _upload(self, content) -> Optional[str]:
         file_name = self._random_file_name(content)
         if not file_name:
             return None
