@@ -1,24 +1,8 @@
 from typing import Optional
-
 import requests
-
 from image_depot import DepotType
 from .base import Depot
 
-TOKEN = ''
-UID = ''
-
-
-def set_config(token: str, uid: str):
-    """
-    :param token: 获取地址: https://www.imgurl.org/vip/manage/mytoken
-    :param uid: 与 token 一起获取
-    :return:
-    """
-    global TOKEN, UID
-    TOKEN = token
-    UID = uid
-
 
 class ImgUrl(Depot):
     @classmethod
@@ -26,7 +10,8 @@ class ImgUrl(Depot):
         return DepotType.ImgUrl
 
     def _upload(self, content) -> Optional[str]:
-        if not TOKEN or not UID:
+        conf = self._config.img_url
+        if not conf.token or not conf.uid:
             return self._set_error('token or uid is empty')
         file_name = self._random_file_name(content)
         if not file_name:
@@ -35,8 +20,8 @@ class ImgUrl(Depot):
             'file': (file_name, content)
         }
         data = {
-            'uid': UID,
-            'token': TOKEN,
+            'uid': conf.uid,
+            'token': conf.token,
         }
         response = requests.post('https://www.imgurl.org/api/v2/upload', files=files, data=data)
         if response.status_code != 200:
